[edk2-devel] [PATCH 1/1] Ext4Pkg: Fix typos discovered by SpellCheck

Marvin Häuser mhaeuser at posteo.de
Thu Jan 26 18:06:53 UTC 2023


Fix typos discovered by SpellCheck, which were discovered as part of the
initial CI enablement effort.

Cc: Pedro Falcato <pedro.falcato at gmail.com>
Signed-off-by: Marvin Häuser <mhaeuser at posteo.de>
---
 Features/Ext4Pkg/Ext4Dxe/BlockMap.c   |  6 +++---
 Features/Ext4Pkg/Ext4Dxe/Directory.c  |  2 +-
 Features/Ext4Pkg/Ext4Dxe/Ext4Dxe.h    | 16 ++++++++--------
 Features/Ext4Pkg/Ext4Dxe/Extents.c    |  4 ++--
 Features/Ext4Pkg/Ext4Dxe/File.c       |  2 +-
 Features/Ext4Pkg/Ext4Dxe/Inode.c      |  2 +-
 Features/Ext4Pkg/Ext4Dxe/Superblock.c |  6 +++---
 Features/Ext4Pkg/Ext4Dxe/Symlink.c    |  2 +-
 8 files changed, 20 insertions(+), 20 deletions(-)

diff --git a/Features/Ext4Pkg/Ext4Dxe/Directory.c b/Features/Ext4Pkg/Ext4Dxe/Directory.c
index ba781bad968c..456916453952 100644
--- a/Features/Ext4Pkg/Ext4Dxe/Directory.c
+++ b/Features/Ext4Pkg/Ext4Dxe/Directory.c
@@ -16,7 +16,7 @@
    @param[in]      Entry   Pointer to a EXT4_DIR_ENTRY.
    @param[out]      Ucs2FileName   Pointer to an array of CHAR16's, of size EXT4_NAME_MAX + 1.
 
-   @retval EFI_SUCCESS              The filename was succesfully retrieved and converted to UCS2.
+   @retval EFI_SUCCESS              The filename was successfully retrieved and converted to UCS2.
    @retval EFI_INVALID_PARAMETER    The filename is not valid UTF-8.
    @retval !EFI_SUCCESS             Failure.
 **/
diff --git a/Features/Ext4Pkg/Ext4Dxe/Ext4Dxe.h b/Features/Ext4Pkg/Ext4Dxe/Ext4Dxe.h
index 41779dad855f..f608def7c9eb 100644
--- a/Features/Ext4Pkg/Ext4Dxe/Ext4Dxe.h
+++ b/Features/Ext4Pkg/Ext4Dxe/Ext4Dxe.h
@@ -155,7 +155,7 @@ Ext4UnrefDentry (
 
    @param[out]     Partition Partition structure to fill with filesystem
 details.
-   @retval EFI_SUCCESS       Parsing was succesful and the partition is a
+   @retval EFI_SUCCESS       Parsing was successful and the partition is a
                              valid ext4 partition.
 **/
 EFI_STATUS
@@ -322,7 +322,7 @@ Ext4ReadInode (
    @param[out]     Buffer        Pointer to the buffer.
    @param[in]      Offset        Offset of the read.
    @param[in out]  Length        Pointer to the length of the buffer, in bytes.
-                                 After a succesful read, it's updated to the
+                                 After a successful read, it's updated to the
 number of read bytes.
 
    @return Status of the read operation.
@@ -355,7 +355,7 @@ cover.
    @param[out]     Extent        Pointer to the output buffer, where the extent
 will be copied to.
 
-   @retval EFI_SUCCESS        Retrieval was succesful.
+   @retval EFI_SUCCESS        Retrieval was successful.
    @retval EFI_NO_MAPPING     Block has no mapping.
 **/
 EFI_STATUS
@@ -946,7 +946,7 @@ Ext4StrCmpInsensitive (
    @param[in]      Entry   Pointer to a EXT4_DIR_ENTRY.
    @param[out]      Ucs2FileName   Pointer to an array of CHAR16's, of size EXT4_NAME_MAX + 1.
 
-   @retval EFI_SUCCESS              The filename was succesfully retrieved and converted to UCS2.
+   @retval EFI_SUCCESS              The filename was successfully retrieved and converted to UCS2.
    @retval EFI_INVALID_PARAMETER    The filename is not valid UTF-8.
    @retval !EFI_SUCCESS             Failure.
 **/
@@ -1106,7 +1106,7 @@ Ext4CalculateBlockGroupDescChecksum (
   );
 
 /**
-   Verifies the existance of a particular RO compat feature set.
+   Verifies the existence of a particular RO compat feature set.
    @param[in]      Partition           Pointer to the opened EXT4 partition.
    @param[in]      RoCompatFeatureSet  Feature set to test.
 
@@ -1116,7 +1116,7 @@ Ext4CalculateBlockGroupDescChecksum (
   ((Partition->FeaturesRoCompat & RoCompatFeatureSet) == RoCompatFeatureSet)
 
 /**
-   Verifies the existance of a particular compat feature set.
+   Verifies the existence of a particular compat feature set.
    @param[in]      Partition           Pointer to the opened EXT4 partition.
    @param[in]      CompatFeatureSet  Feature set to test.
 
@@ -1126,7 +1126,7 @@ Ext4CalculateBlockGroupDescChecksum (
   ((Partition->FeaturesCompat & CompatFeatureSet) == CompatFeatureSet)
 
 /**
-   Verifies the existance of a particular compat feature set.
+   Verifies the existence of a particular compat feature set.
    @param[in]      Partition           Pointer to the opened EXT4 partition.
    @param[in]      IncompatFeatureSet  Feature set to test.
 
@@ -1217,7 +1217,7 @@ Ext4GetExtentLength (
    @param[in]      LogicalBlock  Block number which the returned extent must cover.
    @param[out]     Extent        Pointer to the output buffer, where the extent will be copied to.
 
-   @retval EFI_SUCCESS        Retrieval was succesful.
+   @retval EFI_SUCCESS        Retrieval was successful.
    @retval EFI_NO_MAPPING     Block has no mapping.
 **/
 EFI_STATUS
diff --git a/Features/Ext4Pkg/Ext4Dxe/Extents.c b/Features/Ext4Pkg/Ext4Dxe/Extents.c
index f1964426d276..e1001d0a4292 100644
--- a/Features/Ext4Pkg/Ext4Dxe/Extents.c
+++ b/Features/Ext4Pkg/Ext4Dxe/Extents.c
@@ -219,7 +219,7 @@ Ext4ExtentIdxLeafBlock (
    @param[in]      LogicalBlock  Block number which the returned extent must cover.
    @param[out]     Extent        Pointer to the output buffer, where the extent will be copied to.
 
-   @retval EFI_SUCCESS        Retrieval was succesful.
+   @retval EFI_SUCCESS        Retrieval was successful.
    @retval EFI_NO_MAPPING     Block has no mapping.
 **/
 EFI_STATUS
@@ -615,7 +615,7 @@ Ext4GetExtentLength (
   IN CONST EXT4_EXTENT  *Extent
   )
 {
-  // If it's an unintialized extent, the true length is ee_len - 2^15
+  // If it's an uninitialized extent, the true length is ee_len - 2^15
   if (EXT4_EXTENT_IS_UNINITIALIZED (Extent)) {
     return Extent->ee_len - EXT4_EXTENT_MAX_INITIALIZED;
   }
diff --git a/Features/Ext4Pkg/Ext4Dxe/File.c b/Features/Ext4Pkg/Ext4Dxe/File.c
index 04198a53bfc0..8dfe324255f4 100644
--- a/Features/Ext4Pkg/Ext4Dxe/File.c
+++ b/Features/Ext4Pkg/Ext4Dxe/File.c
@@ -105,7 +105,7 @@ Ext4IsLastPathSegment (
    @param[in out] File         Pointer to the file we're opening.
    @param[in]     OpenMode     Mode in which to open the file.
 
-   @return           True if the open was succesful, false if we don't have
+   @return           True if the open was successful, false if we don't have
                      enough permissions.
 **/
 STATIC
diff --git a/Features/Ext4Pkg/Ext4Dxe/Inode.c b/Features/Ext4Pkg/Ext4Dxe/Inode.c
index 5ccb4d2bfc42..e44b5638599f 100644
--- a/Features/Ext4Pkg/Ext4Dxe/Inode.c
+++ b/Features/Ext4Pkg/Ext4Dxe/Inode.c
@@ -76,7 +76,7 @@ Ext4CalculateInodeChecksum (
    @param[out]     Buffer        Pointer to the buffer.
    @param[in]      Offset        Offset of the read.
    @param[in out]  Length        Pointer to the length of the buffer, in bytes.
-                                 After a succesful read, it's updated to the number of read bytes.
+                                 After a successful read, it's updated to the number of read bytes.
 
    @return Status of the read operation.
 **/
diff --git a/Features/Ext4Pkg/Ext4Dxe/Superblock.c b/Features/Ext4Pkg/Ext4Dxe/Superblock.c
index edee051c41e8..5a3c7f478187 100644
--- a/Features/Ext4Pkg/Ext4Dxe/Superblock.c
+++ b/Features/Ext4Pkg/Ext4Dxe/Superblock.c
@@ -151,7 +151,7 @@ Ext4VerifySuperblockChecksum (
    Opens and parses the superblock.
 
    @param[out]     Partition Partition structure to fill with filesystem details.
-   @retval EFI_SUCCESS       Parsing was succesful and the partition is a
+   @retval EFI_SUCCESS       Parsing was successful and the partition is a
                              valid ext4 partition.
 **/
 EFI_STATUS
@@ -203,7 +203,7 @@ Ext4OpenSuperblock (
 
   // Now, check for the feature set of the filesystem
   // It's essential to check for this to avoid filesystem corruption and to avoid
-  // accidentally opening an ext2/3/4 filesystem we don't understand, which would be disasterous.
+  // accidentally opening an ext2/3/4 filesystem we don't understand, which would be disastrous.
 
   if (Partition->FeaturesIncompat & ~gSupportedIncompatFeat) {
     DEBUG ((
@@ -312,7 +312,7 @@ Ext4OpenSuperblock (
     return EFI_OUT_OF_RESOURCES;
   }
 
-  // Note that the cast below is completely safe, because EXT4_FILE is a specialisation of EFI_FILE_PROTOCOL
+  // Note that the cast below is completely safe, because EXT4_FILE is a specialization of EFI_FILE_PROTOCOL
   Status = Ext4OpenVolume (&Partition->Interface, (EFI_FILE_PROTOCOL **)&Partition->Root);
 
   if (EFI_ERROR (Status)) {
diff --git a/Features/Ext4Pkg/Ext4Dxe/Symlink.c b/Features/Ext4Pkg/Ext4Dxe/Symlink.c
index 0905417ffb88..19b357ac6ba0 100644
--- a/Features/Ext4Pkg/Ext4Dxe/Symlink.c
+++ b/Features/Ext4Pkg/Ext4Dxe/Symlink.c
@@ -201,7 +201,7 @@ Ext4ReadSymlink (
   CHAR16      *Needle;
 
   //
-  // Assume that we alread read Inode via Ext4ReadInode
+  // Assume that we already read Inode via Ext4ReadInode
   // Skip reading, just check encryption flag
   //
   if ((File->Inode->i_flags & EXT4_ENCRYPT_FL) != 0) {
diff --git a/Features/Ext4Pkg/Ext4Dxe/BlockMap.c b/Features/Ext4Pkg/Ext4Dxe/BlockMap.c
index 2bc629fe9d38..8fee4476a5ac 100644
--- a/Features/Ext4Pkg/Ext4Dxe/BlockMap.c
+++ b/Features/Ext4Pkg/Ext4Dxe/BlockMap.c
@@ -131,7 +131,7 @@ Ext4GetBlockPath (
 
 /**
    @brief Get an extent from a block map
-   Note: Also parses file holes and creates uninitialised extents from them.
+   Note: Also parses file holes and creates uninitialized extents from them.
 
    @param[in]  Buffer          Buffer of block pointers
    @param[in]  IndEntries      Number of entries in this block pointer table
@@ -173,7 +173,7 @@ Ext4GetExtentInBlockMap (
       }
     }
 
     // We mark the extent as uninitialised, although there's a difference between uninit
     // extents and file holes.
     Extent->ee_len = EXT4_EXTENT_MAX_INITIALIZED + Count;
     return;
@@ -206,7 +206,7 @@ Ext4GetExtentInBlockMap (
    @param[in]      LogicalBlock  Block number which the returned extent must cover.
    @param[out]     Extent        Pointer to the output buffer, where the extent will be copied to.
 
-   @retval EFI_SUCCESS        Retrieval was succesful.
+   @retval EFI_SUCCESS        Retrieval was successful.
    @retval EFI_NO_MAPPING     Block has no mapping.
 **/
 EFI_STATUS
@@ -173,7 +173,7 @@ Ext4GetExtentInBlockMap (
     }
 
-    // We mark the extent as uninitialised, although there's a difference between uninit
+    // We mark the extent as uninitialized, although there's a difference between uninit
     // extents and file holes.
     Extent->ee_len = EXT4_EXTENT_MAX_INITIALIZED + Count;
-- 
2.39.1



-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.
View/Reply Online (#99088): https://edk2.groups.io/g/devel/message/99088
Mute This Topic: https://groups.io/mt/96548973/1813853
Group Owner: devel+owner at edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub [edk2-devel-archive at redhat.com]
-=-=-=-=-=-=-=-=-=-=-=-




More information about the edk2-devel-archive mailing list